@@ -23,7 +23,7 @@ from __future__ import absolute_import
 # @author: see AUTHORS file
 
 import inspect
-from openpyxl.compat import unicode, basestring
+from openpyxl.compat import unicode, basestring, safe_string, zip
 from openpyxl.descriptors import Descriptor, Strict
 
 BASE_TYPES = (str, unicode, float, int)
@@ -32,7 +32,7 @@ BASE_TYPES = (str, unicode, float, int)
 class HashableObject(Strict):
     """Define how to hash property classes."""
     __fields__ = ()
-    __slots__ = __fields__
+    __slots__ = ('_key',) + __fields__
     __base__ = False
 
     @property
@@ -81,18 +81,49 @@ class HashableObject(Strict):
     def __str__(self):
         return self.__print__(defaults=True)
 
-    @property
-    def __key(self):
+    def _make_key(self):
         """Use a tuple of fields as the basis for a key"""
-        return [getattr(self, x) for x in self.__fields__]
+        self._key = hash(tuple(getattr(self, x) for x in self.__fields__))
 
     def __hash__(self):
-        return hash(str(self.__key))
+        if not hasattr(self, '_key'):
+            self._make_key()
+        return self._key
 
     def __eq__(self, other):
         if isinstance(other, self.__class__):
-            return self.__key == other.__key
-        return self.__key == other
+            if not hasattr(self, '_key'):
+                self._make_key()
+            if not hasattr(other, '_key'):
+                other._make_key()
+            return self._key == other._key
+        return self._key == other
 
     def __ne__(self, other):
         return not self == other
+
+    def __add__(self, other):
+        vals = {}
+        for attr in self.__fields__:
+            vals[attr] = getattr(self, attr) or getattr(other, attr)
+        return self.__class__(**vals)
+
+    def __sub__(self, other):
+        vals = {}
+        if (self is other) or (self == other):
+            return
+        for attr in self.__fields__:
+            if not getattr(other, attr) and getattr(self, attr):
+                vals[attr] = getattr(self, attr)
+        return self.__class__(**vals)
+
+
+    def __iter__(self):
+        """
+        Dictionary interface for easier serialising.
+        All values converted to strings
+        """
+        for key in self.__fields__:
+            value = getattr(self, key)
+            if bool(value):
+                yield key, safe_string(value)
