@@ -36,17 +36,16 @@ class TestGradientFill:
     def test_sequence(self, GradientFill):
         colors = [Color(BLACK), Color(WHITE)]
         gf = GradientFill(stop=colors)
-        assert gf.stop == colors
+        assert gf.stop == tuple(colors)
 
 
     def test_invalid_sequence(self, GradientFill):
         colors = [BLACK, WHITE]
         with pytest.raises(TypeError):
-            gf = GradientFill(stop=colors)
+            GradientFill(stop=colors)
 
 
     def test_dict_interface(self, GradientFill):
         gf = GradientFill(degree=90, left=1, right=2, top=3, bottom=4)
         assert dict(gf) == {'bottom': "4", 'degree': "90", 'left':"1",
                             'right': "2", 'top': "3", 'type': 'linear'}
-
