@@ -9,7 +9,7 @@ class TestFont:
         assert f.size == 11
         assert f.bold is False
         assert f.italic is False
-        assert f.underline == 'none'
+        assert f.underline is None
         assert f.strikethrough is False
         assert f.color.value == '00000000'
         assert f.color.type == 'rgb'
