@@ -4,14 +4,12 @@ from io import BytesIO
 import pytest
 
 from openpyxl.xml.functions import start_tag, end_tag, tag, XMLGenerator
-from openpyxl.xml.constants import SHEET_MAIN_NS
 
-
-@pytest.fixture(scope="class")
+@pytest.fixture
 def doc():
     return BytesIO()
 
-@pytest.fixture(scope="class")
+@pytest.fixture
 def root(doc):
     return XMLGenerator(doc)
 
@@ -25,7 +23,7 @@ class TestSimpleTag:
     def test_end_tag(self, doc, root):
         """"""
         end_tag(root, "blah")
-        assert doc.getvalue() == b"<start></blah>"
+        assert doc.getvalue() == b"</blah>"
 
 
 class TestTagBody:
@@ -36,7 +34,7 @@ class TestTagBody:
 
     def test_end_tag(self, doc, root):
         end_tag(root, "end")
-        assert doc.getvalue() == b"<start>just words</end>"
+        assert doc.getvalue() == b"</end>"
 
 
 def test_start_tag_attrs(doc, root):
@@ -45,5 +43,5 @@ def test_start_tag_attrs(doc, root):
 
 
 def test_tag(doc, root):
-    t = tag(root, "start", {'height':"10"}, "words")
+    tag(root, "start", {'height':"10"}, "words")
     assert doc.getvalue() == b"""<start height="10">words</start>"""
